@@ -14,7 +14,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_codeguru_reviewer.type_defs import (
     ListRepositoryAssociationsResponseTypeDef,
@@ -42,7 +42,7 @@ class ListRepositoryAssociationsPaginator(Boto3Paginator):
         Names: List[str] = None,
         Owners: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListRepositoryAssociationsResponseTypeDef, None, None]:
+    ) -> Iterator[ListRepositoryAssociationsResponseTypeDef]:
         """
         [ListRepositoryAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
         """
